==> RecalAddon4.2.jar: addon/evo_reds_alienpack/kubejs_scripts/alien_codex.js <==
global.alienevo_alien_29 = ['reds_aliens:goop']
global.alienevo_randomization_29 = [false]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_28 = ['reds_aliens:spidermonkey']
global.alienevo_randomization_28 = [false]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_27 = ['reds_aliens:brainstorm']
global.alienevo_randomization_27 = [false]; // Determine if you want your alien to be unlocked through mistransformation.

// rath
global.alienevo_alien_30 = ['reds_aliens:rath']
global.alienevo_randomization_30 = [true]; 

global.alienevo_regen_30 = [0];
global.alienevo_scale_30 = [55]; 
global.alienevo_textcolor_30 = [0x23c235];
global.alienevo_background_30 = ['alienevo:textures/block/machined_metal.png']; 

global.alienevo_30_10k_uniforms = [true, false, false]; 
global.alienevo_30_default_uniforms = [true, false, false]; 
global.alienevo_30_prototype_uniforms = [true, false, false];

global.alienevo_30_prototype_skincolor_palette_1 = ["d25828", "c65122", "b4491f", "a1411c", "803416"];
global.alienevo_30_prototype_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_prototype_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];

global.alienevo_30_default_skincolor_palette_1 = ["de7323", "d37024", "c86920", "bb6421", "9f561d"];
global.alienevo_30_default_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_default_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];

global.alienevo_30_10k_skincolor_palette_1 = ["d25828", "c65122", "b4491f", "a1411c", "803416"];
global.alienevo_30_10k_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_10k_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];


global.alienevo_regen_34 = [0];
global.alienevo_scale_34 = [55]; 
global.alienevo_textcolor_34 = [0x23c235];
global.alienevo_background_34 = ['alienevo:textures/block/machined_metal.png']; 

global.alienevo_34_10k_uniforms = [true, false, false]; 
global.alienevo_34_default_uniforms = [true, false, false]; 
global.alienevo_34_prototype_uniforms = [true, false, false];

global.alienevo_34_10k_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_10k_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

global.alienevo_34_default_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_default_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

global.alienevo_34_prototype_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_prototype_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

// INTERFACE VALUES
global.alienevo_regen_29 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_29 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_29 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_29 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_29_prototype_uniforms = [true, false, false];

global.alienevo_regen_27 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_27 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_27 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_27 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_27_prototype_uniforms = [true, false, false];

// INTERFACE VALUES
global.alienevo_regen_30 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_30 = [45]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_30 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_30 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_30_prototype_uniforms = [true, false, false];

// INTERFACE VALUES
global.alienevo_regen_37 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_37 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_37 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_37 = ['minecraft:textures/block/moss_block.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_37_prototype_uniforms = [true, false, false];

// INTERFACE VALUES
global.alienevo_regen_28 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_28 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_28 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_28 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_28_prototype_uniforms = [true, false, false];

global.alienevo_alien_47 = ['reds_aliens:saiyan']
global.alienevo_alien_48 = ['reds_aliens:cascan']
global.alienevo_randomization_48 = [true]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_49 = ['reds_aliens:surge']
global.alienevo_randomization_49 = [true]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_50 = ['reds_aliens:hotdog']
global.alienevo_randomization_50 = [true]; // Determine if you want your alien to be unlocked through mistransformation.

// INTERFACE VALUES
global.alienevo_regen_49 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_49 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_49 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_49 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_49_prototype_uniforms = [true, false, false];

global.alienevo_regen_50 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_50 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_50 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_50 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_50_prototype_uniforms = [true, false, false];

global.alienevo_regen_48 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_48 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_48 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_48 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_48_prototype_uniforms = [true, true, true];

// Make sure your colors are listed from BRIGHTEST TO DARKEST. You can use as many or as few colors in a palette as you'd like.
global.alienevo_48_default_skincolor_palette_1 = ["3e4b4f", "56676d", "0de0fd", "dd0000", "dd0000"];

// DEFAULT ALIENEVO ALIENS
global.alienevo_randomization_0 = [false];   // null
global.alienevo_randomization_1 = [true];   // Heatblast
global.alienevo_randomization_2 = [true];   // Wildmutt
global.alienevo_randomization_3 = [true];   // Diamondhead
global.alienevo_randomization_4 = [true];   // XLR8
global.alienevo_randomization_5 = [true];   // Grey Matter
global.alienevo_randomization_6 = [true];   // Four Arms
global.alienevo_randomization_7 = [true];   // Stinkfly
global.alienevo_randomization_8 = [true];   // Ripjaws
global.alienevo_randomization_9 = [true];   // Upgrade
global.alienevo_randomization_10 = [true];  // Ghostfreak
global.alienevo_randomization_11 = [true];   // Cannonbolt
global.alienevo_randomization_34 = [true];   // Jetray
global.alienevo_randomization_31 = [true];   // Swampfire

==> RecalAddon4.7.jar: addon/evo_reds_alienpack/kubejs_scripts/alien_codex.js <==
global.alienevo_alien_29 = ['reds_aliens:goop']
global.alienevo_randomization_29 = [true]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_28 = ['reds_aliens:spidermonkey']
global.alienevo_randomization_28 = [false]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_27 = ['reds_aliens:brainstorm']
global.alienevo_randomization_27 = [false]; // Determine if you want your alien to be unlocked through mistransformation.

// rath
global.alienevo_alien_30 = ['reds_aliens:rath']
global.alienevo_randomization_30 = [true]; 

global.alienevo_regen_30 = [0];
global.alienevo_scale_30 = [55]; 
global.alienevo_textcolor_30 = [0x23c235];
global.alienevo_background_30 = ['alienevo:textures/block/machined_metal.png']; 

global.alienevo_30_10k_uniforms = [true, false, false]; 
global.alienevo_30_default_uniforms = [true, false, false]; 
global.alienevo_30_prototype_uniforms = [true, true, true];

global.alienevo_30_prototype_skincolor_palette_1 = ["d25828", "c65122", "b4491f", "a1411c", "803416"];
global.alienevo_30_prototype_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_prototype_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];

global.alienevo_30_default_skincolor_palette_1 = ["de7323", "d37024", "c86920", "bb6421", "9f561d"];
global.alienevo_30_default_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_default_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];

global.alienevo_30_10k_skincolor_palette_1 = ["d25828", "c65122", "b4491f", "a1411c", "803416"];
global.alienevo_30_10k_skincolor_palette_2 = ["ffffff", "edf4f4", "d6dfe1", "bdc7cf", "97a2b0"];
global.alienevo_30_10k_skincolor_palette_3 = ["3a3333", "2c2828", "232020", "171515", "000000"];

global.alienevo_30_10k_glowcolor_1 = ["ebd63a", "d8a717"];
global.alienevo_30_default_glowcolor_1 = ["b1ff4d", "8fff00"];
global.alienevo_30_prototype_glowcolor_1 = ["ebd63a", "d8a717"];

global.alienevo_29_10k_glowcolor_1 = ["b3ff40", "8ed721"];
global.alienevo_29_default_glowcolor_1 = ["a9f756", "96ed32", "86e123", "72d72f", "50bf20"];
global.alienevo_29_default_glowcolor_2 = ["47a51c", "86e123", "97ed32", "72d72e", "86e123"];
global.alienevo_29_prototype_glowcolor_1 = ["72d72e", "8ed721"];

// aerophibian
global.alienevo_alien_34 = ['alienevo_aliens:aerophibian']
global.alienevo_randomization_34 = [false]; 

global.alienevo_regen_34 = [0];
global.alienevo_scale_34 = [55]; 
global.alienevo_textcolor_34 = [0x23c235];
global.alienevo_background_34 = ['alienevo:textures/block/machined_metal.png']; 

global.alienevo_34_10k_uniforms = [true, true, true]; 
global.alienevo_34_default_uniforms = [true, false, false]; 
global.alienevo_34_prototype_uniforms = [true, true, true];

global.alienevo_34_10k_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_10k_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

global.alienevo_34_default_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_default_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

global.alienevo_34_prototype_skincolor_palette_1 = ["c80f12", "af071c", "920920", "7c0525", "6e0721"];
global.alienevo_34_prototype_skincolor_palette_2 = ["ffd120", "f4b51a", "e09210", "cd7809", "b75b05"];

global.alienevo_34_10k_glowcolor_1 = ["b3ff40", "8ed721"];
global.alienevo_34_default_glowcolor_1 = ["b3ff40", "8ed721"];
global.alienevo_34_prototype_glowcolor_1 = ["b3ff40", "8ed721"];


// INTERFACE VALUES
global.alienevo_regen_29 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_29 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_29 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_29 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_29_prototype_uniforms = [true, false, false];

global.alienevo_regen_27 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_27 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_27 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_27 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_27_prototype_uniforms = [true, false, false];

// INTERFACE VALUES
global.alienevo_regen_30 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_30 = [45]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_30 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_30 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render

// INTERFACE VALUES
global.alienevo_regen_37 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_37 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_37 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_37 = ['minecraft:textures/block/moss_block.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_37_prototype_uniforms = [true, false, false];

// INTERFACE VALUES
global.alienevo_regen_28 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_28 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_28 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_28 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_28_prototype_uniforms = [true, false, false];

global.alienevo_alien_47 = ['reds_aliens:saiyan']
global.alienevo_alien_48 = ['reds_aliens:cascan']
global.alienevo_randomization_48 = [true]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_49 = ['reds_aliens:surge']
global.alienevo_randomization_49 = [true]; // Determine if you want your alien to be unlocked through mistransformation.
global.alienevo_alien_50 = ['reds_aliens:hotdog']
global.alienevo_randomization_50 = [false]; // Determine if you want your alien to be unlocked through mistransformation.

// INTERFACE VALUES
global.alienevo_regen_49 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_49 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_49 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_49 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_49_prototype_uniforms = [true, false, false];

global.alienevo_regen_50 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_50 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_50 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_50 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_50_prototype_uniforms = [true, false, false];

global.alienevo_regen_48 = [0]; // A faux regen value to represent your alien's healing capability. Values 0 thru 10. Does not effect gameplay.
global.alienevo_scale_48 = [55]; // Scale of the alien preview render. 55 is default
global.alienevo_textcolor_48 = [0x968815]; // Valid (RRGGBB format)
global.alienevo_background_48 = ['minecraft:textures/block/dirt.png']; // Tiled texture that appears behind the alien preview render
global.alienevo_48_prototype_uniforms = [true, true, true];

// Make sure your colors are listed from BRIGHTEST TO DARKEST. You can use as many or as few colors in a palette as you'd like.
global.alienevo_48_default_skincolor_palette_1 = ["3e4b4f", "56676d", "0de0fd", "dd0000", "dd0000"];

// DEFAULT ALIENEVO ALIENS
global.alienevo_randomization_0 = [false];   // null
global.alienevo_randomization_1 = [true];   // Heatblast
global.alienevo_randomization_2 = [true];   // Wildmutt
global.alienevo_randomization_3 = [true];   // Diamondhead
global.alienevo_randomization_4 = [true];   // XLR8
global.alienevo_randomization_5 = [true];   // Grey Matter
global.alienevo_randomization_6 = [true];   // Four Arms
global.alienevo_randomization_7 = [true];   // Stinkfly
global.alienevo_randomization_8 = [true];   // Ripjaws
global.alienevo_randomization_9 = [true];   // Upgrade
global.alienevo_randomization_10 = [true];  // Ghostfreak
global.alienevo_randomization_11 = [true];   // Cannonbolt
global.alienevo_randomization_34 = [true];   // Jetray
global.alienevo_randomization_31 = [true];   // Swampfire
